#!/usr/bin/env python3
#
#  setband.py
#
#  Change bands.
#
#  Copyright (c) 2023 by Matt Roberts,
#  All rights reserved.
#
#  License: GPL3
#

import socket
import select
import json
import time
import sys
import os

#
#  main()
#
def main():
	# mapping from band to bits
	bits = {
		'160m': b'00',
		'80m': b'01',
		'40m': b'02',
		'30m': b'03',
		'20m': b'04',
		'17m': b'05',
		'15m': b'06',
		'12m': b'07',
		'10m': b'08',
		'6m': b'09',
		'-': None, # placeholder
		'+': None, # placeholder
	}

	if not sys.argv[1:]:
		sys.stderr.write("Specify band in { 160m, 80m, 40m, 30m, 20m, 17m, 15m, 12m, 10m, 6m, +, - }\n")
		return
	arg = sys.argv[1]

	if arg not in bits.keys():
		sys.stderr.write("Invalid band.\n")
		return
	
	# TS590 band codes
	# 00: 1.8 MHz band
	# 01: 3.5 MHz band
	# 02: 7 MHz band
	# 03: 10 MHz band
	# 04: 14 MHz band
	# 05: 18 MHz band
	# 06: 21 MHz band
	# 07: 24 MHz band
	# 08: 28 MHz band
	# 09: 50 MHz band

	# connect to the socket (TODO: make this configurable)
	s = socket.create_connection(('localhost', 4532))

	# now decide what to do
	if arg == '+':
		# send 'encoder up' command
		s.send(b'W CH0; 0\r');
	elif arg == '-':
		# send 'encoder down' command
		s.send(b'W CH1; 0\r');
	else:
		# send 'band up' command
		s.send(b'W BU' + bits[arg] + b'; 0\r');

		# send 'copy A->B' command
		s.send(b'W VV; 0\r');

	# close the socket
	s.close()

if __name__ == '__main__':
	main()

# EOF
